@@ -5,11 +5,8 @@
 #include <time.h>
 #include <stdlib.h>
 #include <math.h>
-#include <gtk/gtkmain.h>
-#include <libgnome/gnome-macros.h>
 #include <libart_lgpl/art_affine.h>
 #include "eog-transform.h"
-#include "libeog-marshal.h"
 
 #define PROFILE 1
 
@@ -135,11 +132,8 @@ eog_transform_apply   (EogTransform *trans, GdkPixbuf *pixbuf, EogJob *job)
 
 	/* for every destination pixel (dx,dy) compute the source pixel (sx, sy) and copy the
 	   color values */
-	for (y = 0; y < dest_height; y++) {
-		for (x = 0; x < dest_width; x++) {
-
-			dx = dest_top_left.x + x;
-			dy = dest_top_left.y + y;
+	for (y = 0, dy = dest_top_left.y; y < dest_height; y++, dy++) {
+		for (x = 0, dx = dest_top_left.x; x < dest_width; x++, dx++) {
 			
 			sx = dx * inverted[0] + dy * inverted[2] + inverted[4];
 			sy = dx * inverted[1] + dy * inverted[3] + inverted[5];
@@ -206,6 +200,18 @@ eog_transform_is_identity (EogTransform *trans)
 	return art_affine_equal (identity, trans->priv->affine);
 }
 
+EogTransform*
+eog_transform_identity_new ()
+{
+	EogTransform *trans; 
+
+	trans = EOG_TRANSFORM (g_object_new (EOG_TYPE_TRANSFORM, 0));
+	
+	art_affine_identity (trans->priv->affine);
+
+	return trans;
+}
+
 EogTransform* 
 eog_transform_rotate_new (int degree)
 {
@@ -250,6 +256,70 @@ eog_transform_scale_new  (double sx, double sy)
 	return trans;
 }
 
+EogTransform*
+eog_transform_new (EogTransformType type)
+{
+	EogTransform *trans = NULL;
+	EogTransform *temp1 = NULL, *temp2 = NULL;
+
+	switch (type) {
+	case EOG_TRANSFORM_NONE:
+		trans = eog_transform_identity_new ();
+		break;
+	case EOG_TRANSFORM_FLIP_HORIZONTAL:
+		trans = eog_transform_flip_new (EOG_TRANSFORM_FLIP_HORIZONTAL);
+		break;
+	case EOG_TRANSFORM_ROT_180:
+		trans = eog_transform_rotate_new (180);
+		break;
+	case EOG_TRANSFORM_FLIP_VERTICAL:
+		trans = eog_transform_flip_new (EOG_TRANSFORM_FLIP_VERTICAL);
+		break;
+	case EOG_TRANSFORM_TRANSPOSE:
+		temp1 = eog_transform_rotate_new (90);
+		temp2 = eog_transform_flip_new (EOG_TRANSFORM_FLIP_HORIZONTAL);
+		trans = eog_transform_compose (temp1, temp2);
+		g_object_unref (temp1);
+		g_object_unref (temp2);
+		break;
+	case EOG_TRANSFORM_ROT_90:
+		trans = eog_transform_rotate_new (90);
+		break;
+	case EOG_TRANSFORM_TRANSVERSE:
+		temp1 = eog_transform_rotate_new (90);
+		temp2 = eog_transform_flip_new (EOG_TRANSFORM_FLIP_VERTICAL);
+		trans = eog_transform_compose (temp1, temp2);
+		g_object_unref (temp1);
+		g_object_unref (temp2);
+		break;
+	case EOG_TRANSFORM_ROT_270:
+		trans = eog_transform_rotate_new (270);
+		break;
+	default:
+		trans = eog_transform_identity_new ();
+		break;
+	}
+
+	return trans;
+}
+
+EogTransformType
+eog_transform_convert_exif_orientation (int orientation)
+{
+	static EogTransformType lookup [8] = {EOG_TRANSFORM_NONE, 
+					      EOG_TRANSFORM_FLIP_HORIZONTAL, 
+					      EOG_TRANSFORM_ROT_180, 
+					      EOG_TRANSFORM_FLIP_VERTICAL, 
+					      EOG_TRANSFORM_TRANSPOSE, 
+					      EOG_TRANSFORM_ROT_90, 
+					      EOG_TRANSFORM_TRANSVERSE, 
+					      EOG_TRANSFORM_ROT_270};
+	
+	return (orientation >= 1 && orientation <= 8 ? 
+				lookup[orientation - 1] : 
+				EOG_TRANSFORM_NONE);
+}
+
 EogTransformType
 eog_transform_get_transform_type (EogTransform *trans)
 {
@@ -287,5 +357,17 @@ eog_transform_get_transform_type (EogTransform *trans)
 		return EOG_TRANSFORM_FLIP_VERTICAL;
 	}
 
+	art_affine_rotate (affine, 90);
+	art_affine_flip (affine, affine, TRUE, FALSE);
+	if (art_affine_equal (affine, priv->affine)) {
+		return EOG_TRANSFORM_TRANSPOSE;
+	}
+
+	art_affine_rotate (affine, 90);
+	art_affine_flip (affine, affine, FALSE, TRUE);
+	if (art_affine_equal (affine, priv->affine)) {
+		return EOG_TRANSFORM_TRANSVERSE;
+	}
+
 	return EOG_TRANSFORM_NONE;
 }
