@@ -20,10 +20,6 @@
  */
 #include <config.h>
 #include <math.h>
-#include <string.h>
-#include <glib/gmain.h>
-#include <glib/gmacros.h>
-#include <libgnome/gnome-macros.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkdnd.h>
 
@@ -52,7 +48,6 @@ static GtkTargetEntry drag_types [] = {
 
 /* Used to hold signal handler IDs for models */
 typedef enum {
-	MODEL_SIGNAL_PREPARED,
 	MODEL_SIGNAL_IMAGE_ADDED,
 	MODEL_SIGNAL_IMAGE_REMOVED,
 	MODEL_SIGNAL_LAST
@@ -146,7 +141,6 @@ static void eog_wrap_list_drag_data_get_cb (GtkWidget *widget,
 static void request_update (EogWrapList *wlist);
 static gboolean do_update (EogWrapList *wlist);
 static gint handle_canvas_click (GnomeCanvas *canvas, GdkEventButton *event, gpointer data);
-static gboolean handle_canvas_scroll (GnomeCanvas *canvas, GdkEventScroll *event, gpointer data);
 
 G_DEFINE_TYPE (EogWrapList, eog_wrap_list, GNOME_TYPE_CANVAS)
 
@@ -282,11 +276,6 @@ eog_wrap_list_construct (EogWrapList *wlist)
 				"button-press-event",
 				G_CALLBACK (handle_canvas_click),
 				wlist);
-
-	g_signal_connect_after (G_OBJECT (wlist), 
-			  	"scroll_event",
-			  	G_CALLBACK (handle_canvas_scroll),
-			  	wlist);
 }
 
 
@@ -422,47 +411,6 @@ deselect_all (EogWrapList *wlist)
 	}
 }
 
-static gboolean
-handle_canvas_scroll (GnomeCanvas *canvas, GdkEventScroll *event, gpointer data)
-{
-	EogWrapList *wlist;
-	EogWrapListPrivate *priv;
-
-	g_return_val_if_fail (data != NULL, FALSE);
-	g_return_val_if_fail (EOG_IS_WRAP_LIST (data), FALSE);
-
-	wlist = EOG_WRAP_LIST (data);
-	priv = wlist->priv;
-
-	switch (event->direction) {
-	case GDK_SCROLL_UP:
-		eog_wrap_list_select_single (EOG_WRAP_LIST (wlist), 
-					     EOG_WRAP_LIST_SELECT_LEFT);
-		break;
-
-	case GDK_SCROLL_LEFT:
-		eog_wrap_list_select_single (EOG_WRAP_LIST (wlist), 
-					     EOG_WRAP_LIST_SELECT_LEFT);
-		break;
-
-	case GDK_SCROLL_DOWN:
-		eog_wrap_list_select_single (EOG_WRAP_LIST (wlist), 
-					     EOG_WRAP_LIST_SELECT_RIGHT);
-		break;
-
-	case GDK_SCROLL_RIGHT:
-		eog_wrap_list_select_single (EOG_WRAP_LIST (wlist), 
-					     EOG_WRAP_LIST_SELECT_RIGHT);
-		break;
-
-	default:
-		g_assert_not_reached ();
-		return FALSE;
-	}
-
-	return TRUE;
-}
-
 static gint
 handle_canvas_click (GnomeCanvas *canvas, GdkEventButton *event, gpointer data)
 {
